/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef ACTIONDESCR_H_INCLUDED
#define ACTIONDESCR_H_INCLUDED

#include <BSAction.h>
#include <BSCrystalPathSet.h>
#include <QtXml/QDomElement>
#include <QtCore/QMetaType>

#include "refractionDescr.h"
#include "crystalDescr.h"
#include "rotationDescr.h"

class ErrorOutput;

class ActionDescr
{
public:

	enum ActionType
	{
		ActionAlternative,
		IdentityAction, Rainbow, RainbowSelective, 
		CrystalAction,
		CrystalSelectiveAction
	};

	ActionDescr();
	ActionDescr(const ActionDescr &actionDescr);

	~ActionDescr();

	const ActionDescr &operator = (const ActionDescr &actionDescr);

	ActionType getActionType() const;
	void setActionType(ActionType _type);

	RefractionDescr *getRefractionDescr() const;
	void setRefractionDescr(RefractionDescr *refractionDescr);

	QString getRSPathString() const;
	void setRSPathString(QString path);

	QString getPathSetString() const;
	void setPathSetString(QString pathSet);

	CrystalDescr *getCrystalDescr() const;
	void setCrystalDescr(CrystalDescr *crystalDescr);

	RotationDescr *getRotationDescr() const;
	void setRotationDescr(RotationDescr *rotationDescr);

	ActionDescr *getDefaultActionDescr() const;
	void setDefaultActionDescr(ActionDescr *actionDescr);

	int getAdditionalActionCount() const;
	const ActionDescr &getAdditionalActionDescr(int index) const;
	float getAdditionalActionProbability(int index) const;
	void appendAdditionalAction(const ActionDescr &actionDescr, float probability);

	BlueSky::Action *getAction() const;
	QDomElement getDomElement() const;
	QString getActionName() const;

	static ActionDescr fromDomElement(QDomElement node, QString nodeName, ErrorOutput *output);

private:

	static unsigned long long rainbowSelectivePathsFromDomElement(QDomElement node, ErrorOutput *output);
	static QString pathSetStringFromDomElement(QDomElement node, ErrorOutput *output);

	BlueSky::CrystalPathSet *parsePathSet(int faceCount) const;

	ActionType type;
	RefractionDescr *refraction;
	unsigned long long rsPath;
	QString pathSetString;
	CrystalDescr *crystal;
	RotationDescr *rotation;

	ActionDescr *defaultAction;

	QList<ActionDescr> additionalActions;
	QList<float> additionalProbabilities;
};

Q_DECLARE_METATYPE(ActionDescr)

#endif
