/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BLUESKYXMLSCRIPT_H_INCLUDED
#define BLUESKYXMLSCRIPT_H_INCLUDED

#include <QtXml/QtXml>

#include "actionDescr.h"
#include "cameraDescr.h"
#include "sunDescr.h"

class Simulation;
class ErrorOutput;

class BlueSkyXmlScript
{
public:

	BlueSkyXmlScript(QDomDocument document);
	~BlueSkyXmlScript();

	bool parse(ErrorOutput *output);

	float getSunAzimuth();
	float getSunAltitude();

	const ActionDescr &getActionDescr();

	CameraDescr::CameraType getCameraType();
	int getCameraResolution();

	Simulation *getSimulation(int simThreads);
	QString getDescription();
	QString getBriefDescription();
	QString getScriptName();

	QString toText();

	void setSunDescr(const SunDescr &_sunDescr);
	void setActionDescr(const ActionDescr &_actionDescr);
	void setCameraDescr(const CameraDescr &_cameraDescr);

	static BlueSkyXmlScript *fromText(QString text, ErrorOutput *output);
	static BlueSkyXmlScript *fromFile(QString path, ErrorOutput *output);

private:

	ActionDescr actionDescr;
	CameraDescr cameraDescr;
	SunDescr    sunDescr;

	QString description;
	QString briefDescription;
	QString scriptName;

	QDomDocument domDocument;
};

#endif
