/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef CRYSTALDESCR_H_INCLUDED
#define CRYSTALDESCR_H_INCLUDED

#include <BSCrystal.h>
#include <QtXml/QDomElement>

class ErrorOutput;

class CrystalDescr
{
public:

	enum CrystalType
	{
		Diamond, Prism
	};

	CrystalDescr();
	CrystalDescr(const CrystalDescr &crystalDescr);

	~CrystalDescr();

	const CrystalDescr &operator = (const CrystalDescr &crystalDescr);
	
	CrystalType getCrystalType() const;
	void setCrystalType(CrystalType _type);

	int getJoiningFacesCount() const;
	void setJoiningFacesCount(int _joiningFacesCount);
	
	float getElongation() const;
	void setElongation(float _elongation);

	BlueSky::Crystal *getCrystal() const;
	QDomElement getDomElement() const;

	QString getCrystalName() const;

	static CrystalDescr fromDomElement(QDomElement node, QString nodeName, ErrorOutput *output);

private:

	CrystalType type;
	int joiningFacesCount;
	float elongation;
};

#endif
