/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef DISPLAYSETTINGSWIDGET_H_INCLUDED
#define DISPLAYSETTINGSWIDGET_H_INCLUDED

#include <QtGui/QWidget>

class QCheckBox;
class QLabel;
class QSlider;

class SkyView;

class DisplaySettingsWidget : public QWidget
{
	Q_OBJECT

public:

	DisplaySettingsWidget(SkyView *_skyView);

	void setOrientation(bool horizontal);

private slots:

	void dynBrightnessToggled(bool checked);
	void useGammaToggled(bool checked);
	void stereographicToggled(bool checked);
	void brightnessValueChanged(int value);
	void gammaValueChanged(int value);
	void backgroundValueChanged(int value);
	void horizonValueChanged(int value);

private:

	QCheckBox *dynBrightnessCheckBox;
	QCheckBox *useGammaCheckBox;
	QCheckBox *stereographicCheckBox;

	QLabel *brightnessLabel;
	QLabel *gammaLabel;
	QLabel *backgroundLabel;
	QLabel *horizonLabel;

	QSlider *brightnessSlider;
	QSlider *gammaSlider;
	QSlider *backgroundSlider;
	QSlider *horizonSlider;

	SkyView *skyView;
};

#endif
