/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef EDITACTIONDIALOG_H_INCLUDED
#define EDITACTIONDIALOG_H_INCLUDED

#include <QtGui/QDialog>

#include "actionDescr.h"
#include "crystalDescr.h"
#include "rotationDescr.h"

class QDoubleSpinBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QLineEdit;
class QPushButton;
class QRadioButton;

class EditActionDialog : public QDialog
{
	Q_OBJECT

public:

	EditActionDialog();
	EditActionDialog(const ActionDescr &actionDescr);

	QString getActionName();
	ActionDescr getActionDescr();

private slots:

	void okButtonPush();
	void editCrystalPush();

	void actionTypeChanged(int index);
	void constRefractionToggled(bool checked);
	void powerRefractionToggled(bool checked);
	void predefinedMaterialToggled(bool checked);

private:

	void createElements();
	void createRefractionGroupBox();
	void createCrystalGroupBox();

	RefractionDescr getRefractionDescr();
	void setRefractionDescr(RefractionDescr *refractionDescr);
	void setCrystalDescr(CrystalDescr *_crystalDescr);
	void setRotationDescr(RotationDescr *_rotationDescr);

	QLabel *descriptionLabel;
	QComboBox *actionTypeComboBox;

	QGroupBox *refractionGroupBox;
	QRadioButton *constRefractionRadioButton;
	QRadioButton *powerRefractionRadioButton;
	QRadioButton *predefinedMaterialRadioButton;

	QGroupBox *powerRefractionGroupBox;
	QDoubleSpinBox *constRefractionSpinBox;
	QDoubleSpinBox *redRefractionSpinBox;
	QDoubleSpinBox *greenRefractionSpinBox;
	QDoubleSpinBox *blueRefractionSpinBox;
	QComboBox *materialComboBox;

	QGroupBox *pathGroupBox;
	QLineEdit *pathLineEdit;

	QGroupBox *crystalGroupBox;
	QLabel *crystalLabel;
	QPushButton *editCrystalButton;

	QPushButton *okButton;
	QPushButton *cancelButton;

	CrystalDescr crystalDescr;
	RotationDescr rotationDescr;
};

#endif
