/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef EDITCRYSTALDIALOG_H_INCLUDED
#define EDITCRYSTALDIALOG_H_INCLUDED

#include <QtGui/QDialog>

#include "crystalDescr.h"
#include "rotationDescr.h"

class QDoubleSpinBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QSpinBox;
class QTableWidget;

class EditCrystalDialog : public QDialog
{
	Q_OBJECT

public:

	EditCrystalDialog(const CrystalDescr &crystalDescr, const RotationDescr &rotationDescr);

	QString getCrystalName();
	CrystalDescr getCrystalDescr();
	RotationDescr getRotationDescr();

private slots:

	void crystalShapeChanged(int index);
	void editDefaultRotation();

	void addRotation();
	void editRotation();
	void removeRotation();
	void removeAllRotations();

private:

	void addRotation(const RotationDescr &rotation, float probability);

	void createElements();

	QLabel *crystalShapeLabel;
	QComboBox *crystalShapeComboBox;

	QLabel *joiningFacesLabel;
	QSpinBox *joiningFacesSpinBox;

	QLabel *elongationLabel;
	QDoubleSpinBox *elongationSpinBox;

	QGroupBox *defaultRotationGroupBox;
	QLabel *defaultRotationLabel;
	QPushButton *editDefaultRotationButton;

	QGroupBox *additionalRotationsGroupBox;
	QTableWidget *rotationTableWidget;
	QPushButton *addRotationButton;
	QPushButton *editRotationButton;
	QPushButton *removeRotationButton;
	QPushButton *removeAllRotationsButton;

	QPushButton *okButton;
	QPushButton *cancelButton;

	RotationDescr defaultRotationDescr;
};

#endif
