/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef QBS_MAIN_WINDOW_H_INCLUDED
#define QBS_MAIN_WINDOW_H_INCLUDED

#include <QtGui/QMainWindow>

#include "sunDescr.h"
#include "actionDescr.h"
#include "cameraDescr.h"

class QAction;
class QComboBox;
class QDockWidget;
class QDoubleSpinBox;
class QGroupBox;
class QLabel;
class QMenu;
class QPushButton;
class QSpinBox;
class QTableWidget;
class QTabWidget;
class QTextEdit;

class Simulation;
class NewSimulationWizard;
class ScriptEditor;
class SkyView;
class ErrorOutputWidget;
class DisplaySettingsWidget;
class BlueSkyXmlScript;

class MainWindow : public QMainWindow
{
	Q_OBJECT

public:

	MainWindow();
	~MainWindow();

protected:

	void closeEvent(QCloseEvent *event);

public slots:

	void newEmptyScript();
	void showNewSimWizard();
	void open();
	bool save();
	bool saveAs();
	void saveImage();
	void startSimulation();
	void pauseSimulation();
	void stopSimulation();

	void about();

	void scriptChanged();
	void parseScript();

private slots:

	void displaySettingsLocationChanged(Qt::DockWidgetArea area);

private:

	void createActions();
	void createMenus();
	void createToolBars();
	void createStatusBar();
	void createDockWindows();
	void createTabs();
	
	void createConnections();

	bool maybeSave();
	bool saveScript(QString path);
	bool loadScript(QString path);

	QString currentScriptPath;

	QMenu *fileMenu;
	QMenu *editMenu;
	QMenu *viewMenu;
	QMenu *helpMenu;
	QMenu *simulationMenu;

	QAction *newEmptyScriptAction;
	QAction *newAction;
	QAction *openAction;
	QAction *saveAction;
	QAction *saveAsAction;
	QAction *saveImageAction;
	QAction *settingsAction;
	QAction *exitAction;
	QAction *undoAction;
	QAction *redoAction;
	QAction *cutAction;
	QAction *copyAction;
	QAction *pasteAction;
	QAction *startSimAction;
	QAction *pauseSimAction;
	QAction *stopSimAction;
	QAction *aboutAction;
	QAction *aboutQtAction;

	QToolBar *simulationToolBar;

	QDockWidget *simSettingsDockWidget;
	QDockWidget *outputDockWidget;
	QDockWidget *displaySettingsDockWidget;

	QTabWidget *tabWidget;

	ScriptEditor *scriptEditor;
	QTextEdit *description;
	SkyView *skyView;
	Simulation *simulation;
	ErrorOutputWidget *outputWidget;
	DisplaySettingsWidget *displaySettingsWidget;

	NewSimulationWizard *newSimulationWizard;

/* Simulation settings widget */

private slots:

	void ssDoubleValueChanged(double value);
	void ssIntValueChanged(int value);

	void ssEditDefaultAction();
	void ssAddAction();
	void ssEditAction();
	void ssRemoveAction();
	void ssRemoveAllActions();
	void ssActionsTableChanged(int row, int column);

	void ssCameraTypeChanged(int index);

private:

	bool simSettingsChanged;

	void createSimulationSettingsWidget();
	void setSimSettingsEnabled(bool enabled);

	void ssUpdateScript(BlueSkyXmlScript *script);
	void ssUpdateFromScript(BlueSkyXmlScript *script);

	void ssAddAdditionalAction(const ActionDescr &actionDescr, float probability);

	SunDescr ssGetSunDescr();
	ActionDescr ssGetActionDescr();
	CameraDescr ssGetCameraDescr();

	QWidget *ssWidget;

	QGroupBox *ssSunGroupBox;
	QLabel *ssAzimuthLabel;
	QLabel *ssAltitudeLabel;
	QDoubleSpinBox *ssAzimuthSpinBox;
	QDoubleSpinBox *ssAltitudeSpinBox;

	QGroupBox *ssDefaultActionGroupBox;
	QLabel *ssDefaultActionLabel;
	QPushButton *ssEditDefaultActionButton;

	QGroupBox *ssActionsGroupBox;
	QTableWidget *ssActionsTableWidget;
	QPushButton *ssAddActionButton;
	QPushButton *ssEditActionButton;
	QPushButton *ssRemoveActionButton;
	QPushButton *ssRemoveAllActionsButton;

	QGroupBox *ssCameraGroupBox;
	QLabel *ssCameraTypeLabel;
	QLabel *ssCameraResolutionLabel;
	QComboBox *ssCameraTypeComboBox;
	QSpinBox *ssCameraResolutionSpinBox;

	ActionDescr ssDefaultAction;
};

#endif
