/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef NEWSIMULATIONWIZARD_H_INCLUDED
#define NEWSIMULATIONWIZARD_H_INCLUDED

#include <QtGui/QtGui>

#include "actionDescr.h"
#include "cameraDescr.h"
#include "sunDescr.h"

namespace NewSimulationWizardPages
{
	class IntroPage;
	class ActionsPage;
	class CameraSettingsPage;
	class SunSettingsPage;
	class ExampleSimPage;
	class ConclusionPage;
}

class NewSimulationWizard : public QWizard
{
	Q_OBJECT

public:

	enum
	{
		Page_Intro, Page_Actions, Page_CameraSettings, Page_SunSettings,
		Page_ExampleSim, Page_Conclusion
	};

	NewSimulationWizard(QWidget *parent);

	QString getScriptCode();

private:

	NewSimulationWizardPages::IntroPage *introPage;
	NewSimulationWizardPages::ActionsPage *actionsPage;
	NewSimulationWizardPages::CameraSettingsPage *cameraSettingsPage;
	NewSimulationWizardPages::SunSettingsPage *sunSettingsPage;
	NewSimulationWizardPages::ExampleSimPage *exampleSimPage;
	NewSimulationWizardPages::ConclusionPage *conclusionPage;
};

namespace NewSimulationWizardPages
{
	class IntroPage : public QWizardPage
	{
		Q_OBJECT

	public:

		IntroPage(QWidget *parent = 0);

		int nextId() const;

	private:

		QLabel *topLabel;

		QRadioButton *minimalScriptRadioButton;
		QRadioButton *simWizardRadioButton;
		QRadioButton *exampleSimRadioButton;
	};

	class ActionsPage : public QWizardPage
	{
		Q_OBJECT

	public:

		ActionsPage(QWidget *parent = 0);

		int nextId() const;

		ActionDescr getActionDescr();

	public slots:

		void editDefaultAction();

		void addAction();
		void editAction();
		void removeAction();
		void removeAllActions();

	private:

		ActionDescr defaultAction;

		QLabel *topLabel;
		QLabel *defaultActionLabel;

		QGroupBox *defaultActionGroupBox;
		QGroupBox *additionalActionsGroupBox;

		QTableWidget *actionTableWidget;

		QPushButton *editDefaultActionButton;
		QPushButton *addActionButton;
		QPushButton *editActionButton;
		QPushButton *removeActionButton;
		QPushButton *removeAllActionsButton;
	};

	class CameraSettingsPage : public QWizardPage
	{
		Q_OBJECT

	public:

		CameraSettingsPage(QWidget *parent = 0);

		int nextId() const;

		CameraDescr getCameraDescr();

	private slots:

		void cameraSelected(int index);

	private:

		QLabel *topLabel;
		QLabel *cameraDescription;

		QComboBox *cameraTypeComboBox;

		QSpinBox *cameraResolutionSpinBox;
	};

	class SunSettingsPage : public QWizardPage
	{
		Q_OBJECT

	public:

		SunSettingsPage(QWidget *parent = 0);

		int nextId() const;

		SunDescr getSunDescr();

	private:

		QLabel *topLabel;
		QLabel *azimuthLabel;
		QLabel *altitudeLabel;

		QDoubleSpinBox *azimuthSpinBox;
		QDoubleSpinBox *altitudeSpinBox;
	};

	class ExampleSimPage : public QWizardPage
	{
		Q_OBJECT

	public:

		ExampleSimPage(QWidget *parent = 0);

		int nextId() const;
		
		QString getScriptCode() const;

	private slots:

		void selectedScriptChanged(int index);

	private:

		void findExamples();

		QLabel *topLabel;

		QListWidget *examplesListWidget;
		QLabel *exampleDescription;

		QStringList examplesDescriptions;
		QStringList examplesPaths;
	};

	class ConclusionPage : public QWizardPage
	{
		Q_OBJECT

	public:

		ConclusionPage(QWidget *parent = 0);

		int nextId() const;

	private:

		QLabel *topLabel;
	};
};

#endif
