/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#include "probabilitySpinBoxDelegate.h"

#include <QtGui/QtGui>

ProbabilitySpinBoxDelegate::ProbabilitySpinBoxDelegate(QObject *parent)
	: QItemDelegate(parent)
{	
}
	
QWidget *ProbabilitySpinBoxDelegate::createEditor(
		QWidget *parent, 
		const QStyleOptionViewItem &/* option */,
		const QModelIndex &/* index */) const
{
	QDoubleSpinBox *editor = new QDoubleSpinBox(parent);
	editor->setDecimals(4);
	editor->setRange(0.0, 1.0);
	editor->setSingleStep(0.01);

	return editor;
}

void ProbabilitySpinBoxDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
{
	double value = index.model()->data(index, Qt::EditRole).toDouble();
	
	QDoubleSpinBox *spinBox = static_cast<QDoubleSpinBox*>(editor);
	spinBox->setValue(value);
}

void ProbabilitySpinBoxDelegate::setModelData(
	QWidget *editor, 
	QAbstractItemModel *model, 
	const QModelIndex &index) const
{
	QDoubleSpinBox *spinBox = static_cast<QDoubleSpinBox*>(editor);
	spinBox->interpretText();
	double value = spinBox->value();

	model->setData(index, value, Qt::EditRole);
}

void ProbabilitySpinBoxDelegate::updateEditorGeometry(
	QWidget *editor, 
	const QStyleOptionViewItem &option, 
	const QModelIndex &/* index */) const
{
	editor->setGeometry(option.rect);
}
