/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef REFRACTIONDESCR_H_INCLUDED
#define REFRACTIONDESCR_H_INCLUDED

#include <BSRefractionPower.h>
#include <QtXml/QDomElement>

class ErrorOutput;

class RefractionDescr
{
public:

	enum RefractionType
	{
		RefractionConst, RefractionPower, PredefinedMaterial
	};

	RefractionDescr();
	RefractionDescr(const RefractionDescr &refractionDescr);
	~RefractionDescr();

	const RefractionDescr &operator = (const RefractionDescr &refractionDescr);

	RefractionType getRefractionType() const;
	void setRefractionType(RefractionType _type);

	float getConstRefractiveIndex() const;
	void setConstRefractiveIndex(float refractiveIndex);

	float getPowerRIShift() const;
	float getPowerRIScale() const;
	float getPowerRIPower() const;
	void setPowerRI(float shift, float scale, float power);

	float getPowerRIRed() const;
	float getPowerRIGreen() const;
	float getPowerRIBlue() const;
	void setPowerRIRgb(float rn, float gn, float bn);

	BlueSky::RefractionPower::Material getMaterial() const;
	void setMaterial(BlueSky::RefractionPower::Material _material);

	BlueSky::Refraction *getRefraction() const;
	QDomElement getDomElement() const;

	static RefractionDescr fromDomElement(QDomElement node, QString nodeName, ErrorOutput *output);

private:

	bool fitRgb2powerRI(float rn, float gn, float bn);

	RefractionType type;

	float constRefractiveIndex;
	float powerRIShift;
	float powerRIScale;
	float powerRIPower;

	BlueSky::RefractionPower::Material material;
};

#endif
