/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef ROTATIONDESCR_H_INCLUDED
#define ROTATIONDESCR_H_INCLUDED

#include <BSRotation.h>
#include <QtXml/QDomElement>
#include <QtCore/QMetaType>

class ErrorOutput;

class RotationDescr
{
public:

	enum RotationType
	{
		RotationAlternative,
		RandomUniformRotation, RotationX90Y, RotationX90ZY, RotationXY, RotationY, 
		RotationZY
	};

	RotationDescr();
	RotationDescr(const RotationDescr &rotationDescr);

	~RotationDescr();

	const RotationDescr &operator = (const RotationDescr &rotationDescr);

	RotationType getRotationType() const;
	void setRotationType(RotationType _type);

	bool isDeviated() const;
	void setDeviated(bool _deviated);

	float getDeviation() const;
	void setDeviation(float _deviation);

	RotationDescr *getDefaultRotationDescr() const;
	void setDefaultRotationDescr(RotationDescr *rotationDescr);

	int getAdditionalRotationCount() const;
	const RotationDescr &getAdditionalRotationDescr(int index) const;
	float getAdditionalRotationProbability(int index) const;
	void appendAdditionalRotation(const RotationDescr &rotationDescr, float probability);

	BlueSky::Rotation *getRotation() const;
	QDomElement getDomElement() const;
	QString getRotationName() const;

	static RotationDescr fromDomElement(QDomElement node, QString nodeName, ErrorOutput *output);

private:

	RotationType type;

	bool deviated;
	float deviation;

	RotationDescr *defaultRotation;

	QList<RotationDescr> additionalRotations;
	QList<float> additionalProbabilities;
};

Q_DECLARE_METATYPE(RotationDescr)

#endif
