/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#include "settings.h"

#include <QtGui/QtGui>

#ifndef DEFAULT_LANGUAGE
#define DEFAULT_LANGUAGE "pl"
#endif

Settings::Settings()
{
	threadCountLabel = new QLabel(tr("Number of simulation threads"));
	languageLabel = new QLabel(tr("Language"));

	threadCountSpinBox = new QSpinBox();
	threadCountSpinBox->setRange(1, 16);
	languageComboBox = new QComboBox();
	languageComboBox->addItem("English");
	languageComboBox->addItem("Polski");

	okButton = new QPushButton(tr("Ok"));
	connect(okButton, SIGNAL(pressed()), this, SLOT(accept()));

	QGridLayout *buttonLayout = new QGridLayout();
	buttonLayout->addWidget(okButton, 0, 1);
	buttonLayout->setColumnStretch(0, 10);

	QGridLayout *layout = new QGridLayout();
	layout->addWidget(threadCountLabel, 0, 0);
	layout->addWidget(languageLabel, 1, 0);
	layout->addWidget(threadCountSpinBox, 0, 1);
	layout->addWidget(languageComboBox, 1, 1);
	layout->addLayout(buttonLayout, 2, 0, 1, 2);

	setLayout(layout);

	QSettings settings("BlueSky", "QtBlueSky");
	threadCountSpinBox->setValue(settings.value("simThreads", 4).toInt());
	QString lang = settings.value("language", DEFAULT_LANGUAGE).toString();

	if (lang == "pl")
		languageComboBox->setCurrentIndex(1);
}

Settings *Settings::instance()
{
	if (!singleton)
		singleton = new Settings();
	return singleton;
}

int Settings::getThreadCount()
{
	return threadCountSpinBox->value();
}

QString Settings::getLanguage()
{
	switch (languageComboBox->currentIndex())
	{
	case 0:
		return "en";
	case 1:
		return "pl";
	default:
		return "";
	}
}

void Settings::writeSettings()
{
	QSettings settings("BlueSky", "QtBlueSky");
	settings.setValue("simThreads", threadCountSpinBox->value());
	settings.setValue("language", getLanguage());
}

void Settings::updateTranslation()
{
	threadCountLabel->setText(tr("Number of simulation threads"));
	languageLabel->setText(tr("Language"));
}

QString Settings::qtBlueSkyVersion()
{
	return "0.1.0";
}

Settings *Settings::singleton = NULL;
