/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef SKYVIEW_H_INCLUDED
#define SKYVIEW_H_INCLUDED

#include <QtGui/QtGui>
#include <BSAction.h>
#include <BSCamera.h>

class Simulation;
class SkyViewDrawingThread;

class SkyView : public QLabel
{
	Q_OBJECT

public:

	SkyView(Simulation *sim);
	~SkyView();

	void updateSimulation(Simulation *sim);

	void setUseDynamicBrightness(bool value);
	void setUseGamma(bool value);
	void setStereographic(bool value);
	void setBrightness(float value);
	void setGamma(float value);
	void setBackgroundBrightness(float value);
	void setHorizonOpacity(float value);

	QImage getImage();

public slots:

	void updateSkyView();
	void setPixmap();

protected:

	void mouseMoveEvent(QMouseEvent *event);
	void mousePressEvent(QMouseEvent *event);
	void resizeEvent(QResizeEvent *event);
	void wheelEvent(QWheelEvent *event);

private:

	float xRot;
	float yRot;

	bool useDynamicBrightness;
	bool useGamma;
	bool stereographic;
	float brightness;
	float gamma;
	float backgroundBrightness;
	float horizonOpacity;

	float zoomFactor;

	BlueSky::Camera *camera;

	QPoint lastPos;

	SkyViewDrawingThread *drawingThread;

	QPixmap newPixmap;
	friend class SkyViewDrawingThread;
};

#endif
