/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_CAMERA_H_INCLUDED
#define BS_CAMERA_H_INCLUDED

#include "BSObject.h"

#include "BSPhoton.h"

namespace BlueSky
{

//! Abstract class representing camera.
class Camera : public Object
{
public:

	//! Destructor of Camera
	/*!
	 * \remarks Use delete operator when you are absolutely sure that there is
	 * no references to removed object. Betters solution is remRef() method or
	 * ObjectManager class.
	 */
	inline virtual ~Camera()
	{
	}

	//! Collects photon.
	/*!
	 * \param[in] ph A Photon which is collected.
	 */
	virtual void collect(const Photon& ph) = 0;

	//! Gets color registred in given direction
	/*!
	 * \remarks A direction means direction of photons which activated reqested
	 * cell on camera. This direction is opposite to direction in which camera
	 * looks.
	 *
	 * \param[in] direction Requested direction.
	 *
	 * \return Color registered on given direction.
	 */
	virtual Vector3f getDataByDirection(const Vector3f& direction) const = 0;

	//! Gets a resolution of camera.
	/*!
	 * \return Resolution of camrera.
	 */
	virtual int getResolution() const = 0;

	//! Cleanup camera data.
	/*! Resets all camera data.
	 */
	virtual void clean() = 0;
};

}

#endif
