/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_CONSTROTATION_H_INCLUDED
#define BS_CONSTROTATION_H_INCLUDED

#include "BSRotation.h"

namespace BlueSky
{

//! Rotation model with constant roation.
/*!
 * \remarks This is a dynamic Object, so it can be created only by new operator.
 * If you want to use local objects of ConstRotation, use an ObjectManager class.
 */
class ConstRotation : public Rotation
{
private:

	Quaternionf rotation;

public:

	//! Creates new ConstRotation with identity rotation
	inline ConstRotation()
	{
		rotation = Quaternionf::UNIT;
	}

	//! Crates new ConstRotation with given rotation.
	/*!
	 * \param[in] _rotation Constant value of rotation.
	 */
	inline ConstRotation(const Quaternionf &_rotation)
	{
		rotation = _rotation;
	}

	//! Creates new ConstRotation aroud given axis by given angle.
	/*!
	 * \param[in] angle Angle of rotation
	 * \param[in] axis  Axis of rotation
	 */
	inline ConstRotation(float angle, const Vector3f& axis)
	{
		rotation.fromAngleAxis(angle, axis);
	}

	//! Destructor of ConstRotation
	inline ~ConstRotation()
	{
	}

	//! Gets rotation.
	/*!
	 * \return Constant rotation.
	 */
	inline Quaternionf getRotation()
	{
		return rotation;
	}
};

}

#endif
