/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#include "BSAction.h"
#include "BSCrystal.h"
#include "BSRefraction.h"
#include "BSRotation.h"

namespace BlueSky
{

//! Action representing refractions and reflections on given crystal.
/*!
 * \remark This is a dynamic Object, so can be created only by new operator.
 * If you want to use local object of CrystalAction, use ObjectManager class.
 */
class CrystalAction : public Action
{
private:

	Crystal *crystal;
	Refraction *refraction;
	Rotation *rotation;

public:

	//! Creates new CrystalAction object.
	/*! Rotation of created crystal is random with uniform distribution.
	 * Default refraction model is RefractionPower(RefractionPower::ICE).
	 *
	 * \param[in] _crystal Crystal.
	 */
	CrystalAction(Crystal *_crystal);

	//! Creates new CrystalAction object.
	/*! Default refraction model is RefractionPower(RefractionPower::ICE).
	 *
	 * \param[in] _crystal Crystal.
	 * \param[in] _rotation Rotation model.
	 */
	CrystalAction(Crystal *_crystal, Rotation *_rotation);

	//! Creates new CrystalAction object.
	/*! Rotation of created crystal is random with uniform distribution.
	 *
	 * \param[in] _crystal Crystal.
	 * \param[in] _refraction Refraction model.
	 */
	CrystalAction(Crystal *_crystal, Refraction *_refraction);

	//! Creates new CrystalAction object.
	/*!
	 * \param[in] _crystal Crystal.
	 * \param[in] _refraction Refraction model.
	 * \param[in] _rotation Rotation model.
	 */
	CrystalAction(Crystal *_crystal, Refraction *_refraction, Rotation *_rotation);

	//! Destructor of CrystalAction.
	~CrystalAction();

	//! Change directon of given Photon.
	/*! \param[in] ph Photon before interaction.
	 * \return A new Photon after interaction.
	 */
	Photon action(Photon ph);
};

}
