/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_GAUSSIANDEVIATION_H_INCLUDED
#define BS_GAUSSIANDEVIATION_H_INCLUDED

#include "BSRotation.h"

namespace BlueSky
{

//! Random deviation on rotation with Gaussian distribution.
/*!
 * \remarks This is a dynamic Object, so it can be created only by new operator.
 * if you want to use local object of GaussianDeviation, use ObjectManager
 * class.
 */
class GaussianDeviation : public Rotation
{
private:

	float variance;
	Rotation *baseRotation;

public:

	//! Creates new GaussianDeviation object with given variance.
	/*! Created deviation will be applied to identity rotation.
	 *
	 * \param[in] _variance Variance of deviation angle.
	 */
	GaussianDeviation(float _variance);

	//! Creates new GaussionDeviation on given rotation model with given variance.
	/*!
	 * \param[in] _variance Variance of deviation angle.
	 * \param[in] _baseRotation Rotation model which will be deviated.
	 */
	GaussianDeviation(float _variance, Rotation *_baseRotation);

	//! Destructor of GaussianDeviation.
	~GaussianDeviation();

	//! Gets randomly deviatied rotation.
	/*!
	 * \return Randomly deviated rotation with Gaussian distribution.
	 */
	Quaternionf getRotation();
};

}

#endif
