/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_PHOTON_H_INCLUDED
#define BS_PHOTON_H_INCLUDED

#include "BSVector3f.h"

namespace BlueSky
{

//! A photon with direction, color and wavelength.
class Photon
{
public:

	//! Direction of photon.
	Vector3f dir;
	//! Color of photon.
	Vector3f color;
	//! Wavelength of photon.
	float    wavelength;

	//! Creates new photon.
	inline Photon()
	{
	}

	//! Creates new photon with given direction, color and wavelength.
	/*!
	 * \param[in] _dir Direction of created photon.
	 * \param[in] _color Color of created photon.
	 * \param[in] _wavelength Wavelength of created photon.
	 */
	inline Photon(const Vector3f& _dir, const Vector3f& _color, const float _wavelength) :
		dir(_dir), color(_color), wavelength(_wavelength)
	{
	}

	//! Creates new photon with given direction and wavelength.
	/*! Color is computed from wavelength.
	 *
	 * \param[in] _dir Direction of created photon.
	 * \param[in] _wavelength Wavelength of created photon.
	 */
	Photon(const Vector3f& _dir, const float _wavelength);
};

}

#endif
