/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_REFRACTIONCONST_H_INCLUDED
#define BS_REFRACTIONCONST_H_INCLUDED

#include "BSRefraction.h"

namespace BlueSky
{

//! Refraction model with constant refractive index.
/*! \remark This is a dynamic Object, so can be created only by new operator.
 * If you want to create local objects of RefractionConst, use ObjectManager 
 * class.
 *
 * \sa RefractionPower, Object, ObjectManager
 */
class RefractionConst : public Refraction
{
private:

	float refractiveIndex;

public:

	//! Create new Refraction object with given constant refractive index.
	/*!
	 * \param[in] _refractiveIndex A constant refractive index.
	 */
	RefractionConst(float _refractiveIndex);

	//! Gets refractive index from wavelength
	/*!
	 * \return Refractive index.
	 */
	inline float getRefractiveIndex(float /*wavelenght*/)
	{
		return refractiveIndex;
	}
};

}

#endif
