/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_ROTATIONX90ZY_H_INCLUDED
#define BS_ROTATIONX90ZY_H_INCLUDED

#include "BSRotation.h"

namespace BlueSky
{

//! Random rotation around Z and Y axis performed after rotation by 90 deg around X axis.
/*! This rotation model is usefull for simulating arcs created by pillar
 * crystals.
 *
 * \remarks This is a dynamic object so it can be created only by new operator.
 * If you want to use local objects of RotationX90ZY, use ObjectManager class.
 */
class RotationX90ZY : public Rotation
{
public:

	//! Creates new RotationX90ZY object.
	inline RotationX90ZY()
	{
	}

	//! Destructor of RotationX90ZY.
	inline ~RotationX90ZY()
	{
	}

	//! Get rotation.
	/*!
	 * \return Quaternionf representing composition of rotations around X axis 
	 * by 90 degrees, around Z axis by random angle and around Y axis by random 
	 * angle.
	 */
	Quaternionf getRotation();
};

}

#endif
