/* ----------------------------------------------------------------------------
This file is part of BlueSky

Copyright (C) 2012 Piotr Polesiuk

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in 
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
---------------------------------------------------------------------------- */

#ifndef BS_ROTATIONXY_H_INCLUDED
#define BS_ROTATIONXY_H_INCLUDED

#include "BSRotation.h"

namespace BlueSky
{

//! Composition of two random rotations: around X axis and around Y axis.
/*! Rotation around X axis is performed as first.
 *
 * \remarks This is a dynamic Object, so it can be created only by new operator.
 * If you want to use local objects of RotationXY, use ObjectManager class.
 */
class RotationXY : public Rotation
{
public:

	//! Creates new RotationXY object.
	inline RotationXY()
	{
	}

	//! Destructor of RotationXY.
	inline ~RotationXY()
	{
	}

	//! Gets random rotation around X and Y axis.
	/*!
	 * \return Quaternionf representing composition of two random rotations:
	 * around X axis at first and around Y axis.
	 */
	Quaternionf getRotation();
};

}

#endif
